@@ -1,4 +1,4 @@
-use ethers::{contract::Abigen, utils::Solc};
+use ethers::{contract::Abigen, solc::Solc};
 
 fn main() -> anyhow::Result<()> {
     let mut args = std::env::args();
@@ -9,10 +9,11 @@ fn main() -> anyhow::Result<()> {
 
     println!("Generating bindings for {}\n", contract);
 
-    // compile it if needed
+    // compile it
     let abi = if contract.ends_with(".sol") {
-        let contracts = Solc::new(&contract).build_raw()?;
-        contracts.get(&contract_name).unwrap().abi.clone()
+        let contracts = Solc::default().compile_source(&contract)?;
+        let abi = contracts.get(&contract, &contract_name).unwrap().abi.unwrap();
+        serde_json::to_string(abi).unwrap()
     } else {
         contract
     };
