@@ -1,12 +1,11 @@
-use ethers::prelude::*;
-use std::time::Duration;
-
 #[tokio::main]
 #[cfg(feature = "ipc")]
 async fn main() -> anyhow::Result<()> {
+    use ethers::prelude::*;
+
     let provider = Provider::connect_ipc("~/.ethereum/geth.ipc")
         .await?
-        .interval(Duration::from_millis(2000));
+        .interval(std::time::Duration::from_millis(2000));
     let block = provider.get_block_number().await?;
     println!("Current block: {}", block);
     let mut stream = provider.watch_blocks().await?.stream();
