@@ -2,8 +2,7 @@
 //! a value if the configured `Quorum` was reached.
 
 use ethers::{prelude::*, utils::Ganache};
-use std::str::FromStr;
-use std::time::Duration;
+use std::{str::FromStr, time::Duration};
 
 #[tokio::main]
 async fn main() -> anyhow::Result<()> {
@@ -11,9 +10,7 @@ async fn main() -> anyhow::Result<()> {
 
     // create a quorum provider with some providers
     let quorum = QuorumProvider::dyn_rpc()
-        .add_provider(WeightedProvider::new(Box::new(Http::from_str(
-            &ganache.endpoint(),
-        )?)))
+        .add_provider(WeightedProvider::new(Box::new(Http::from_str(&ganache.endpoint())?)))
         .add_provider(WeightedProvider::with_weight(
             Box::new(Ws::connect(ganache.ws_endpoint()).await?),
             2,
@@ -22,7 +19,8 @@ async fn main() -> anyhow::Result<()> {
             Box::new(Ws::connect(ganache.ws_endpoint()).await?),
             2,
         ))
-        // the quorum provider will yield the response if >50% of the weighted inner provider returned the same value
+        // the quorum provider will yield the response if >50% of the weighted inner provider
+        // returned the same value
         .quorum(Quorum::Majority)
         .build();
 
